@@ -60,6 +60,8 @@ sub notify {
   return $self;
 }
 
+sub pid { shift->dbh->{pg_pid} }
+
 sub ping { shift->dbh->ping }
 
 sub query {
@@ -144,7 +146,8 @@ sub _watch {
     $self->{handle} => sub {
       my $reactor = shift;
 
-      $self->_notifications;
+      $self->emit('close')->_unwatch
+        if !eval { $self->_notifications; 1 } && $self->is_listening;
       return unless (my $waiting = $self->{waiting}) && $dbh->pg_ready;
       my ($sth, $cb) = @{shift @$waiting}{qw(sth cb)};
 
@@ -185,6 +188,16 @@ L<Mojo::Pg>.
 L<Mojo::Pg::Database> inherits all events from L<Mojo::EventEmitter> and can
 emit the following new ones.
 
+=head2 close
+
+  $db->on(close => sub {
+    my $db = shift;
+    ...
+  });
+
+Emitted when the database connection gets closed while waiting for
+notifications.
+
 =head2 notification
 
   $db->on(notification => sub {
@@ -241,7 +254,7 @@ L<Mojo::Pg::Transaction/"commit"> has been called before it is destroyed.
 
   my $tx = $db->begin;
   $db->query('insert into names values (?)', 'Baerbel');
-  $db->query('insert into names values (?)', 'Wolfgangl');
+  $db->query('insert into names values (?)', 'Wolfgang');
   $tx->commit;
 
 =head2 disconnect
@@ -276,6 +289,12 @@ running.
 
 Send notification with optional payload.
 
+=head2 pid
+
+  my $pid = $db->pid;
+
+Return the process id of the backend server process.
+
 =head2 ping
 
   my $bool = $db->ping;
